Subplot-related attributes and methods
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
Some ``SubplotBase`` methods and attributes have been deprecated and/or moved
to `.SubplotSpec`: ``get_geometry`` (use `.SubplotBase.get_subplotspec`
instead), ``change_geometry`` (use `.SubplotBase.set_subplotspec`
instead), ``is_first_row``, ``is_last_row``, ``is_first_col``,
``is_last_col`` (use the corresponding methods on the `.SubplotSpec`
instance instead), ``update_params`` (now a no-op), ``figbox`` (use
``ax.get_subplotspec().get_geometry(ax.figure)`` instead to recompute
the geometry, or ``ax.get_position()`` to read its current value),
``numRows``, ``numCols`` (use the ``nrows`` and ``ncols`` attribute on the
`.GridSpec` instead).  Likewise, the ``get_geometry``, ``change_geometry``,
``update_params``, and ``figbox`` methods/attributes of `.SubplotDivider` have
been deprecated, with similar replacements.

Axes constructor
~~~~~~~~~~~~~~~~
Parameters of the Axes constructor other than *fig* and *rect* will become
keyword-only in a future version.
